<?php

namespace Drupal\Tests\codes_pool\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\RequirementsPageTrait;

/**
 * Tests collection entities.
 *
 * @group codes_pool
 */
class CollectionTest extends BrowserTestBase {

  use RequirementsPageTrait;

  /**
   * Modules to enable.
   *
   * @var string[]
   */
  protected static $modules = [
    'codes_pool',
    'entities',
    'plugin',
  ];

  /**
   * Tests codes pool collections.
   */
  public function testCollections() {
    $test_file = __DIR__ . '../../fixtures/codes.csv';
    $assert = $this->assertSession();
    $page = $this->getSession()->getPage();

    $admin = $this->createUser([], NULL, TRUE);
    $admin->addRole('administrator');
    $admin->save();
    $this->drupalLogin($admin);

    $this->drupalGet('admin/codes-pool');
    $assert->statusCodeEquals(200);
    $assert->pageTextContains('Manage your code collection.');

    $page->clickLink('Code collections');
    $assert->statusCodeEquals(200);
    $assert->pageTextNotContains('New year 20% offer!');

    $page->clickLink('Add code collection');
    $assert->statusCodeEquals(200);

    $page->fillField('name[0][value]', 'New year 20% offer!');
    $page->fillField('description[0][value]', 'Flat 20% off for your new year purchases.');
    $page->fillField('source[0][target_plugin_id]', 'csv');
    $page->fillField('files[source_0_target_plugin_configuration_csv_file_upload]', $test_file);
    $page->pressButton('Save');
    $assert->statusCodeEquals(200);
    $assert->pageTextContains('New year 20% offer!');

    $page->drupalGet('admin/codes-pool/collections/1/edit');
    $assert->pageTextContains('New year 20% offer!');

    $this->drupalLogout();
  }

}
